OC.L10N.register(
    "contacts",
    {
    "Contacts" : "通訊錄",
    "Download" : "下載",
    "Delete Addressbook" : "刪除通訊錄",
    "Share with users or groups" : "與使用者和群組分享",
    "Delete" : "刪除",
    "can edit" : "可編輯",
    "Address book name" : "通訊錄名稱",
    "Import" : "匯入",
    "No contacts in here" : "這裡沒有聯絡人",
    "Name" : "名稱",
    "Organization" : "組織",
    "Title" : "標題",
    "Add field ..." : "新增欄位…",
    "No search result for {query}" : "沒有結果符合 {query}",
    "Postal code" : "郵遞區號",
    "City" : "城市",
    "State or province" : "州或省",
    "Country" : "國家",
    "Address" : "網址",
    "(new group)" : "（新群組）",
    "Last name" : "姓氏",
    "First name" : "名子",
    "Additional names" : "別名",
    "All contacts" : "所有聯絡人",
    "Not grouped" : "不在群組裡",
    "New contact" : "新聯絡人",
    "{addressbook} shared by {owner}" : "{addressbook} 由 {owner} 分享",
    "Nickname" : "暱稱",
    "Notes" : "筆記",
    "Website" : "網站",
    "Federated Cloud ID" : "聯盟式雲端 ID",
    "Home" : "家目錄",
    "Work" : "工作",
    "Other" : "其他",
    "Groups" : "群組",
    "Birthday" : "生日",
    "Email" : "Email",
    "Instant messaging" : "即時通訊",
    "Phone" : "電話",
    "Mobile" : "行動電話",
    "Fax" : "傳真",
    "Fax home" : "傳真（家）",
    "Fax work" : "傳真（公司）",
    "Pager" : "呼叫器",
    "Voice" : "語音",
    "Settings" : "設定"
},
"nplurals=1; plural=0;");
